"""pyiso2mesh - Iso2Mesh for Python
"""

from .iso2mesh_primitive import (
    meshgrid5,
    meshgrid6,
    latticegrid,
    plotsurf,
    plotasurf,
    plotmesh,
    plottetra,
    meshabox,
    meshacylinder,
    meshanellip,
    meshunitsphere,
    meshasphere,
)

from .iso2mesh_utils import (
    finddisconnsurf,
    surfedge,
    volface,
    extractloops,
    meshconn,
    nodevolume,
    elemvolume,
    neighborelem,
    layersurf,
    faceneighbors,
    edgeneighbors,
    maxsurf,
    flatsegment,
    surfplane,
    surfinterior,
    surfpart,
    surfseeds,
    meshquality,
    meshedge,
    meshface,
    surfacenorm,
    nodesurfnorm,
    uniqedges,
    uniqfaces,
    innersurf,
    outersurf,
    surfvolume,
    insurface,
    advancefront,
    meshreorient,
    mesheuler,
    raytrace,
    elemfacecenter,
    barydualmesh,
    meshcentroid,
)

from .iso2mesh_misc import (
    getexeext,
    rotatevec3d,
    fallbackexeext,
    varargin2struct,
    jsonopt,
)

from .iso2mesh_io import (
    saveinr,
    saveoff,
    saveasc,
    savestl,
    savebinstl,
    mwpath,
    deletemeshfile,
    readtetgen,
    savesurfpoly,
    mcpath,
    readoff,
)

from .iso2mesh_core import (
    s2m,
    surf2mesh,
    sms,
    smoothsurf,
    fillsurf,
    binsurface,
    meshcheckrepair,
    removedupnodes,
    removedupelem,
    vol2restrictedtri,
    removeisolatednode,
)

__version__ = "0.1.0"
__all__ = [
    "meshgrid5",
    "meshgrid6",
    "latticegrid",
    "surfedge",
    "volface",
    "surfplane",
    "surfacenorm",
    "nodesurfnorm",
    "plotsurf",
    "plotasurf",
    "plotmesh",
    "meshcentroid",
    "varargin2struct",
    "jsonopt",
    "finddisconnsurf",
    "surfedge",
    "volface",
    "extractloops",
    "meshconn",
    "nodevolume",
    "elemvolume",
    "neighborelem",
    "layersurf",
    "faceneighbors",
    "edgeneighbors",
    "maxsurf",
    "flatsegment",
    "surfplane",
    "surfinterior",
    "surfpart",
    "surfseeds",
    "meshquality",
    "meshedge",
    "meshface",
    "surfacenorm",
    "nodesurfnorm",
    "uniqedges",
    "uniqfaces",
    "innersurf",
    "outersurf",
    "surfvolume",
    "insurface",
    "advancefront",
    "meshreorient",
    "getexeext",
    "saveinr",
    "saveoff",
    "saveasc",
    "savestl",
    "savebinstl",
    "mwpath",
    "deletemeshfile",
    "readtetgen",
    "savesurfpoly",
    "mcpath",
    "meshabox",
    "meshacylinder",
    "meshanellip",
    "s2m",
    "surf2mesh",
    "sms",
    "smoothsurf",
    "fillsurf",
    "rotatevec3d",
    "readoff",
    "vol2restrictedtri",
    "meshcheckrepair",
    "removedupnodes",
    "removedupelem",
    "removeisolatednode",
    "meshunitsphere",
    "fallbackexeext",
    "meshasphere",
    "mesheuler",
    "raytrace",
    "elemfacecenter",
    "barydualmesh",
]
__license__ = """GNU General Public License v3 and later"""
